@@ -13,7 +13,7 @@ function(link.agentset="links", nl.obj=NULL)
  
   from <- NLReport(paste("map [[[who] of end1] of ?] sort ", link.agentset, collapse=""), nl.obj=nl.obj)        
   to <- NLReport(paste("map [[[who] of end2] of ?] sort ", link.agentset, collapse=""), nl.obj=nl.obj)
-  if(!require(igraph)) stop("RNetLogo::NLGetGraph needs package igraph")
+  #if(!require(igraph)) stop("RNetLogo::NLGetGraph needs package igraph")
   retgraph = graph.data.frame(data.frame(from=from,to=to), directed=TRUE)
 
 # old version (until 0.9.2)  
