@@ -1,8 +1,8 @@
 library(RNetLogo)
 
 # adapt the path
-nl.path <- "C:/Program Files/NetLogo 5.0.5"
-NLStart(nl.path, gui=FALSE, nl.version=5)
+nl.path <- "C:/Program Files/NetLogo 5.1.0"
+NLStart(nl.path, gui=FALSE)
 model.path <- "models/Curricular Models/Urban Suite/Urban Suite - Sprawl Effect.nlogo"
 NLLoadModel(paste(nl.path,model.path,sep="/"))
 NLCommand("random-seed 32453433")
