@@ -13,7 +13,7 @@ m <- dbDriver("SQLite")
 #----
 # TODO: adapt these paths
 #----
-nl.path = "C:/Program Files/NetLogo 5.0.5"
+nl.path = "C:/Program Files/NetLogo 5.1.0"
 database.path = "C:/Users/jthiele/Documents/test_netlogo.db"
 
 # create connection to the database 
@@ -21,7 +21,7 @@ database.path = "C:/Users/jthiele/Documents/test_netlogo.db"
 con <- dbConnect(m, dbname = database.path)
    
 # start NetLogo session
-NLStart(nl.path, nl.version=5, gui=FALSE)
+NLStart(nl.path, gui=FALSE)
 # load a NetLogo Model
 NLLoadModel(paste(c(nl.path,"models/Sample Models/Earth Science/Fire.nlogo"),collapse="/"))
 # setup the model
