@@ -2,8 +2,8 @@
 library(RNetLogo)
 
 # initialization of NetLogo
-nl.path <- "C:/Program Files/NetLogo 5.0.5"
-NLStart(nl.path, nl.version=5, gui=FALSE)
+nl.path <- "C:/Program Files/NetLogo 5.1.0"
+NLStart(nl.path, gui=FALSE)
 model.path <- "models/Sample Models/Earth Science/Fire.nlogo"
 NLLoadModel(paste(nl.path,model.path,sep="/"))
 
